@@ -866,7 +866,7 @@ def concat_and_check(dfs):
     return methods.concat(dfs, axis=1)
 
 
-def concat_unindexed_dataframes(dfs):
+def concat_unindexed_dataframes(dfs, **kwargs):
     name = "concat-" + tokenize(*dfs)
 
     dsk = {
@@ -874,17 +874,17 @@ def concat_unindexed_dataframes(dfs):
         for i in range(dfs[0].npartitions)
     }
 
-    meta = methods.concat([df._meta for df in dfs], axis=1)
+    meta = methods.concat([df._meta for df in dfs], axis=1, **kwargs)
 
     graph = HighLevelGraph.from_collections(name, dsk, dependencies=dfs)
     return new_dd_object(graph, name, meta, dfs[0].divisions)
 
 
-def concat_indexed_dataframes(dfs, axis=0, join="outer"):
+def concat_indexed_dataframes(dfs, axis=0, join="outer", **kwargs):
     """ Concatenate indexed dataframes together along the index """
     warn = axis != 0
     meta = methods.concat(
-        [df._meta for df in dfs], axis=axis, join=join, filter_warning=warn
+        [df._meta for df in dfs], axis=axis, join=join, filter_warning=warn, **kwargs
     )
     empties = [strip_unknown_categories(df._meta) for df in dfs]
 
@@ -910,13 +910,13 @@ def concat_indexed_dataframes(dfs, axis=0, join="outer"):
     return new_dd_object(dsk, name, meta, divisions)
 
 
-def stack_partitions(dfs, divisions, join="outer"):
+def stack_partitions(dfs, divisions, join="outer", **kwargs):
     """Concatenate partitions on axis=0 by doing a simple stack"""
     # Use _meta_nonempty as pandas.concat will incorrectly cast float to datetime
     # for empty data frames. See https://github.com/pandas-dev/pandas/issues/32934.
     meta = make_meta(
         methods.concat(
-            [df._meta_nonempty for df in dfs], join=join, filter_warning=False
+            [df._meta_nonempty for df in dfs], join=join, filter_warning=False, **kwargs
         )
     )
     empty = strip_unknown_categories(meta)
@@ -974,6 +974,7 @@ def concat(
     join="outer",
     interleave_partitions=False,
     ignore_unknown_divisions=False,
+    **kwargs
 ):
     """ Concatenate DataFrames along rows.
 
@@ -1083,7 +1084,7 @@ def concat(
 
     if axis == 1:
         if all(df.known_divisions for df in dasks):
-            return concat_indexed_dataframes(dfs, axis=axis, join=join)
+            return concat_indexed_dataframes(dfs, axis=axis, join=join, **kwargs)
         elif (
             len(dasks) == len(dfs)
             and all(not df.known_divisions for df in dfs)
@@ -1096,7 +1097,7 @@ def concat(
                     " are \n aligned. This assumption is not generally "
                     "safe."
                 )
-            return concat_unindexed_dataframes(dfs)
+            return concat_unindexed_dataframes(dfs, **kwargs)
         else:
             raise ValueError(
                 "Unable to concatenate DataFrame with unknown "
@@ -1114,12 +1115,12 @@ def concat(
                     # remove last to concatenate with next
                     divisions += df.divisions[:-1]
                 divisions += dfs[-1].divisions
-                return stack_partitions(dfs, divisions, join=join)
+                return stack_partitions(dfs, divisions, join=join, **kwargs)
             elif interleave_partitions:
-                return concat_indexed_dataframes(dfs, join=join)
+                return concat_indexed_dataframes(dfs, join=join, **kwargs)
             else:
                 divisions = [None] * (sum([df.npartitions for df in dfs]) + 1)
-                return stack_partitions(dfs, divisions, join=join)
+                return stack_partitions(dfs, divisions, join=join, **kwargs)
         else:
             divisions = [None] * (sum([df.npartitions for df in dfs]) + 1)
-            return stack_partitions(dfs, divisions, join=join)
+            return stack_partitions(dfs, divisions, join=join, **kwargs)
