@@ -1,9 +1,7 @@
-from toolz import merge
 from time import time
 import dask
 from dask import threaded, multiprocessing, local
 from random import randint
-from collections import Iterator
 import matplotlib.pyplot as plt
 
 
